@@ -15,9 +15,7 @@
 #
 import proto  # type: ignore
 
-from google.cloud.recommender_v1.types import insight
-from google.cloud.recommender_v1.types import recommendation
-
+from google.cloud.recommender_v1.types import insight, recommendation
 
 __protobuf__ = proto.module(
     package="google.cloud.recommender.v1",
@@ -93,10 +91,22 @@ class ListInsightsRequest(proto.Message):
             described at https://google.aip.dev/160)
     """
 
-    parent = proto.Field(proto.STRING, number=1,)
-    page_size = proto.Field(proto.INT32, number=2,)
-    page_token = proto.Field(proto.STRING, number=3,)
-    filter = proto.Field(proto.STRING, number=4,)
+    parent = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    page_size = proto.Field(
+        proto.INT32,
+        number=2,
+    )
+    page_token = proto.Field(
+        proto.STRING,
+        number=3,
+    )
+    filter = proto.Field(
+        proto.STRING,
+        number=4,
+    )
 
 
 class ListInsightsResponse(proto.Message):
@@ -115,8 +125,15 @@ class ListInsightsResponse(proto.Message):
     def raw_page(self):
         return self
 
-    insights = proto.RepeatedField(proto.MESSAGE, number=1, message=insight.Insight,)
-    next_page_token = proto.Field(proto.STRING, number=2,)
+    insights = proto.RepeatedField(
+        proto.MESSAGE,
+        number=1,
+        message=insight.Insight,
+    )
+    next_page_token = proto.Field(
+        proto.STRING,
+        number=2,
+    )
 
 
 class GetInsightRequest(proto.Message):
@@ -127,7 +144,10 @@ class GetInsightRequest(proto.Message):
             Required. Name of the insight.
     """
 
-    name = proto.Field(proto.STRING, number=1,)
+    name = proto.Field(
+        proto.STRING,
+        number=1,
+    )
 
 
 class MarkInsightAcceptedRequest(proto.Message):
@@ -136,7 +156,7 @@ class MarkInsightAcceptedRequest(proto.Message):
     Attributes:
         name (str):
             Required. Name of the insight.
-        state_metadata (Sequence[google.cloud.recommender_v1.types.MarkInsightAcceptedRequest.StateMetadataEntry]):
+        state_metadata (Mapping[str, str]):
             Optional. State properties user wish to include with this
             state. Full replace of the current state_metadata.
         etag (str):
@@ -144,9 +164,19 @@ class MarkInsightAcceptedRequest(proto.Message):
             Provides optimistic locking.
     """
 
-    name = proto.Field(proto.STRING, number=1,)
-    state_metadata = proto.MapField(proto.STRING, proto.STRING, number=2,)
-    etag = proto.Field(proto.STRING, number=3,)
+    name = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    state_metadata = proto.MapField(
+        proto.STRING,
+        proto.STRING,
+        number=2,
+    )
+    etag = proto.Field(
+        proto.STRING,
+        number=3,
+    )
 
 
 class ListRecommendationsRequest(proto.Message):
@@ -206,10 +236,22 @@ class ListRecommendationsRequest(proto.Message):
             described at https://google.aip.dev/160)
     """
 
-    parent = proto.Field(proto.STRING, number=1,)
-    page_size = proto.Field(proto.INT32, number=2,)
-    page_token = proto.Field(proto.STRING, number=3,)
-    filter = proto.Field(proto.STRING, number=5,)
+    parent = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    page_size = proto.Field(
+        proto.INT32,
+        number=2,
+    )
+    page_token = proto.Field(
+        proto.STRING,
+        number=3,
+    )
+    filter = proto.Field(
+        proto.STRING,
+        number=5,
+    )
 
 
 class ListRecommendationsResponse(proto.Message):
@@ -229,9 +271,14 @@ class ListRecommendationsResponse(proto.Message):
         return self
 
     recommendations = proto.RepeatedField(
-        proto.MESSAGE, number=1, message=recommendation.Recommendation,
+        proto.MESSAGE,
+        number=1,
+        message=recommendation.Recommendation,
+    )
+    next_page_token = proto.Field(
+        proto.STRING,
+        number=2,
     )
-    next_page_token = proto.Field(proto.STRING, number=2,)
 
 
 class GetRecommendationRequest(proto.Message):
@@ -242,7 +289,10 @@ class GetRecommendationRequest(proto.Message):
             Required. Name of the recommendation.
     """
 
-    name = proto.Field(proto.STRING, number=1,)
+    name = proto.Field(
+        proto.STRING,
+        number=1,
+    )
 
 
 class MarkRecommendationClaimedRequest(proto.Message):
@@ -251,7 +301,7 @@ class MarkRecommendationClaimedRequest(proto.Message):
     Attributes:
         name (str):
             Required. Name of the recommendation.
-        state_metadata (Sequence[google.cloud.recommender_v1.types.MarkRecommendationClaimedRequest.StateMetadataEntry]):
+        state_metadata (Mapping[str, str]):
             State properties to include with this state. Overwrites any
             existing ``state_metadata``. Keys must match the regex
             ``/^[a-z0-9][a-z0-9_.-]{0,62}$/``. Values must match the
@@ -261,9 +311,19 @@ class MarkRecommendationClaimedRequest(proto.Message):
             Provides optimistic locking.
     """
 
-    name = proto.Field(proto.STRING, number=1,)
-    state_metadata = proto.MapField(proto.STRING, proto.STRING, number=2,)
-    etag = proto.Field(proto.STRING, number=3,)
+    name = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    state_metadata = proto.MapField(
+        proto.STRING,
+        proto.STRING,
+        number=2,
+    )
+    etag = proto.Field(
+        proto.STRING,
+        number=3,
+    )
 
 
 class MarkRecommendationSucceededRequest(proto.Message):
@@ -272,7 +332,7 @@ class MarkRecommendationSucceededRequest(proto.Message):
     Attributes:
         name (str):
             Required. Name of the recommendation.
-        state_metadata (Sequence[google.cloud.recommender_v1.types.MarkRecommendationSucceededRequest.StateMetadataEntry]):
+        state_metadata (Mapping[str, str]):
             State properties to include with this state. Overwrites any
             existing ``state_metadata``. Keys must match the regex
             ``/^[a-z0-9][a-z0-9_.-]{0,62}$/``. Values must match the
@@ -282,9 +342,19 @@ class MarkRecommendationSucceededRequest(proto.Message):
             Provides optimistic locking.
     """
 
-    name = proto.Field(proto.STRING, number=1,)
-    state_metadata = proto.MapField(proto.STRING, proto.STRING, number=2,)
-    etag = proto.Field(proto.STRING, number=3,)
+    name = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    state_metadata = proto.MapField(
+        proto.STRING,
+        proto.STRING,
+        number=2,
+    )
+    etag = proto.Field(
+        proto.STRING,
+        number=3,
+    )
 
 
 class MarkRecommendationFailedRequest(proto.Message):
@@ -293,7 +363,7 @@ class MarkRecommendationFailedRequest(proto.Message):
     Attributes:
         name (str):
             Required. Name of the recommendation.
-        state_metadata (Sequence[google.cloud.recommender_v1.types.MarkRecommendationFailedRequest.StateMetadataEntry]):
+        state_metadata (Mapping[str, str]):
             State properties to include with this state. Overwrites any
             existing ``state_metadata``. Keys must match the regex
             ``/^[a-z0-9][a-z0-9_.-]{0,62}$/``. Values must match the
@@ -303,9 +373,19 @@ class MarkRecommendationFailedRequest(proto.Message):
             Provides optimistic locking.
     """
 
-    name = proto.Field(proto.STRING, number=1,)
-    state_metadata = proto.MapField(proto.STRING, proto.STRING, number=2,)
-    etag = proto.Field(proto.STRING, number=3,)
+    name = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    state_metadata = proto.MapField(
+        proto.STRING,
+        proto.STRING,
+        number=2,
+    )
+    etag = proto.Field(
+        proto.STRING,
+        number=3,
+    )
 
 
 __all__ = tuple(sorted(__protobuf__.manifest))
