@@ -16,41 +16,43 @@
 from collections import OrderedDict
 import os
 import re
-from typing import Dict, Optional, Sequence, Tuple, Type, Union
-import pkg_resources
+from typing import Dict, Mapping, Optional, Sequence, Tuple, Type, Union
 
 from google.api_core import client_options as client_options_lib
 from google.api_core import exceptions as core_exceptions
 from google.api_core import gapic_v1
 from google.api_core import retry as retries
 from google.auth import credentials as ga_credentials  # type: ignore
+from google.auth.exceptions import MutualTLSChannelError  # type: ignore
 from google.auth.transport import mtls  # type: ignore
 from google.auth.transport.grpc import SslCredentials  # type: ignore
-from google.auth.exceptions import MutualTLSChannelError  # type: ignore
 from google.oauth2 import service_account  # type: ignore
+import pkg_resources
 
 try:
     OptionalRetry = Union[retries.Retry, gapic_v1.method._MethodDefault]
 except AttributeError:  # pragma: NO COVER
     OptionalRetry = Union[retries.Retry, object]  # type: ignore
 
-from google.cloud.recommender_v1beta1.services.recommender import pagers
-from google.cloud.recommender_v1beta1.types import insight
-from google.cloud.recommender_v1beta1.types import insight_type_config
-from google.cloud.recommender_v1beta1.types import (
-    insight_type_config as gcr_insight_type_config,
-)
-from google.cloud.recommender_v1beta1.types import recommendation
-from google.cloud.recommender_v1beta1.types import recommender_config
-from google.cloud.recommender_v1beta1.types import (
-    recommender_config as gcr_recommender_config,
-)
-from google.cloud.recommender_v1beta1.types import recommender_service
 from google.protobuf import duration_pb2  # type: ignore
 from google.protobuf import field_mask_pb2  # type: ignore
 from google.protobuf import struct_pb2  # type: ignore
 from google.protobuf import timestamp_pb2  # type: ignore
-from .transports.base import RecommenderTransport, DEFAULT_CLIENT_INFO
+
+from google.cloud.recommender_v1beta1.services.recommender import pagers
+from google.cloud.recommender_v1beta1.types import (
+    insight_type_config as gcr_insight_type_config,
+)
+from google.cloud.recommender_v1beta1.types import (
+    recommender_config as gcr_recommender_config,
+)
+from google.cloud.recommender_v1beta1.types import insight
+from google.cloud.recommender_v1beta1.types import insight_type_config
+from google.cloud.recommender_v1beta1.types import recommendation
+from google.cloud.recommender_v1beta1.types import recommender_config
+from google.cloud.recommender_v1beta1.types import recommender_service
+
+from .transports.base import DEFAULT_CLIENT_INFO, RecommenderTransport
 from .transports.grpc import RecommenderGrpcTransport
 from .transports.grpc_asyncio import RecommenderGrpcAsyncIOTransport
 
@@ -67,7 +69,10 @@ class RecommenderClientMeta(type):
     _transport_registry["grpc"] = RecommenderGrpcTransport
     _transport_registry["grpc_asyncio"] = RecommenderGrpcAsyncIOTransport
 
-    def get_transport_class(cls, label: str = None,) -> Type[RecommenderTransport]:
+    def get_transport_class(
+        cls,
+        label: str = None,
+    ) -> Type[RecommenderTransport]:
         """Returns an appropriate transport class.
 
         Args:
@@ -178,7 +183,10 @@ class RecommenderClient(metaclass=RecommenderClientMeta):
 
     @staticmethod
     def insight_path(
-        project: str, location: str, insight_type: str, insight: str,
+        project: str,
+        location: str,
+        insight_type: str,
+        insight: str,
     ) -> str:
         """Returns a fully-qualified insight string."""
         return "projects/{project}/locations/{location}/insightTypes/{insight_type}/insights/{insight}".format(
@@ -198,10 +206,16 @@ class RecommenderClient(metaclass=RecommenderClientMeta):
         return m.groupdict() if m else {}
 
     @staticmethod
-    def insight_type_path(project: str, location: str, insight_type: str,) -> str:
+    def insight_type_path(
+        project: str,
+        location: str,
+        insight_type: str,
+    ) -> str:
         """Returns a fully-qualified insight_type string."""
         return "projects/{project}/locations/{location}/insightTypes/{insight_type}".format(
-            project=project, location=location, insight_type=insight_type,
+            project=project,
+            location=location,
+            insight_type=insight_type,
         )
 
     @staticmethod
@@ -215,11 +229,15 @@ class RecommenderClient(metaclass=RecommenderClientMeta):
 
     @staticmethod
     def insight_type_config_path(
-        project: str, location: str, insight_type: str,
+        project: str,
+        location: str,
+        insight_type: str,
     ) -> str:
         """Returns a fully-qualified insight_type_config string."""
         return "projects/{project}/locations/{location}/insightTypes/{insight_type}/config".format(
-            project=project, location=location, insight_type=insight_type,
+            project=project,
+            location=location,
+            insight_type=insight_type,
         )
 
     @staticmethod
@@ -233,7 +251,10 @@ class RecommenderClient(metaclass=RecommenderClientMeta):
 
     @staticmethod
     def recommendation_path(
-        project: str, location: str, recommender: str, recommendation: str,
+        project: str,
+        location: str,
+        recommender: str,
+        recommendation: str,
     ) -> str:
         """Returns a fully-qualified recommendation string."""
         return "projects/{project}/locations/{location}/recommenders/{recommender}/recommendations/{recommendation}".format(
@@ -253,10 +274,18 @@ class RecommenderClient(metaclass=RecommenderClientMeta):
         return m.groupdict() if m else {}
 
     @staticmethod
-    def recommender_path(project: str, location: str, recommender: str,) -> str:
+    def recommender_path(
+        project: str,
+        location: str,
+        recommender: str,
+    ) -> str:
         """Returns a fully-qualified recommender string."""
-        return "projects/{project}/locations/{location}/recommenders/{recommender}".format(
-            project=project, location=location, recommender=recommender,
+        return (
+            "projects/{project}/locations/{location}/recommenders/{recommender}".format(
+                project=project,
+                location=location,
+                recommender=recommender,
+            )
         )
 
     @staticmethod
@@ -269,10 +298,16 @@ class RecommenderClient(metaclass=RecommenderClientMeta):
         return m.groupdict() if m else {}
 
     @staticmethod
-    def recommender_config_path(project: str, location: str, recommender: str,) -> str:
+    def recommender_config_path(
+        project: str,
+        location: str,
+        recommender: str,
+    ) -> str:
         """Returns a fully-qualified recommender_config string."""
         return "projects/{project}/locations/{location}/recommenders/{recommender}/config".format(
-            project=project, location=location, recommender=recommender,
+            project=project,
+            location=location,
+            recommender=recommender,
         )
 
     @staticmethod
@@ -285,7 +320,9 @@ class RecommenderClient(metaclass=RecommenderClientMeta):
         return m.groupdict() if m else {}
 
     @staticmethod
-    def common_billing_account_path(billing_account: str,) -> str:
+    def common_billing_account_path(
+        billing_account: str,
+    ) -> str:
         """Returns a fully-qualified billing_account string."""
         return "billingAccounts/{billing_account}".format(
             billing_account=billing_account,
@@ -298,9 +335,13 @@ class RecommenderClient(metaclass=RecommenderClientMeta):
         return m.groupdict() if m else {}
 
     @staticmethod
-    def common_folder_path(folder: str,) -> str:
+    def common_folder_path(
+        folder: str,
+    ) -> str:
         """Returns a fully-qualified folder string."""
-        return "folders/{folder}".format(folder=folder,)
+        return "folders/{folder}".format(
+            folder=folder,
+        )
 
     @staticmethod
     def parse_common_folder_path(path: str) -> Dict[str, str]:
@@ -309,9 +350,13 @@ class RecommenderClient(metaclass=RecommenderClientMeta):
         return m.groupdict() if m else {}
 
     @staticmethod
-    def common_organization_path(organization: str,) -> str:
+    def common_organization_path(
+        organization: str,
+    ) -> str:
         """Returns a fully-qualified organization string."""
-        return "organizations/{organization}".format(organization=organization,)
+        return "organizations/{organization}".format(
+            organization=organization,
+        )
 
     @staticmethod
     def parse_common_organization_path(path: str) -> Dict[str, str]:
@@ -320,9 +365,13 @@ class RecommenderClient(metaclass=RecommenderClientMeta):
         return m.groupdict() if m else {}
 
     @staticmethod
-    def common_project_path(project: str,) -> str:
+    def common_project_path(
+        project: str,
+    ) -> str:
         """Returns a fully-qualified project string."""
-        return "projects/{project}".format(project=project,)
+        return "projects/{project}".format(
+            project=project,
+        )
 
     @staticmethod
     def parse_common_project_path(path: str) -> Dict[str, str]:
@@ -331,10 +380,14 @@ class RecommenderClient(metaclass=RecommenderClientMeta):
         return m.groupdict() if m else {}
 
     @staticmethod
-    def common_location_path(project: str, location: str,) -> str:
+    def common_location_path(
+        project: str,
+        location: str,
+    ) -> str:
         """Returns a fully-qualified location string."""
         return "projects/{project}/locations/{location}".format(
-            project=project, location=location,
+            project=project,
+            location=location,
         )
 
     @staticmethod
@@ -521,7 +574,6 @@ class RecommenderClient(metaclass=RecommenderClientMeta):
         recommender.*.list IAM permission for the specified insight
         type.
 
-
         .. code-block:: python
 
             from google.cloud import recommender_v1beta1
@@ -614,12 +666,20 @@ class RecommenderClient(metaclass=RecommenderClientMeta):
         )
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # This method is paged; wrap the response in a pager, which provides
         # an `__iter__` convenience method.
         response = pagers.ListInsightsPager(
-            method=rpc, request=request, response=response, metadata=metadata,
+            method=rpc,
+            request=request,
+            response=response,
+            metadata=metadata,
         )
 
         # Done; return the response.
@@ -637,7 +697,6 @@ class RecommenderClient(metaclass=RecommenderClientMeta):
         r"""Gets the requested insight. Requires the recommender.*.get IAM
         permission for the specified insight type.
 
-
         .. code-block:: python
 
             from google.cloud import recommender_v1beta1
@@ -711,7 +770,12 @@ class RecommenderClient(metaclass=RecommenderClientMeta):
         )
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -721,9 +785,7 @@ class RecommenderClient(metaclass=RecommenderClientMeta):
         request: Union[recommender_service.MarkInsightAcceptedRequest, dict] = None,
         *,
         name: str = None,
-        state_metadata: Sequence[
-            recommender_service.MarkInsightAcceptedRequest.StateMetadataEntry
-        ] = None,
+        state_metadata: Mapping[str, str] = None,
         etag: str = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
@@ -738,7 +800,6 @@ class RecommenderClient(metaclass=RecommenderClientMeta):
         Requires the recommender.*.update IAM permission for the
         specified insight.
 
-
         .. code-block:: python
 
             from google.cloud import recommender_v1beta1
@@ -768,7 +829,7 @@ class RecommenderClient(metaclass=RecommenderClientMeta):
                 This corresponds to the ``name`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-            state_metadata (Sequence[google.cloud.recommender_v1beta1.types.MarkInsightAcceptedRequest.StateMetadataEntry]):
+            state_metadata (Mapping[str, str]):
                 Optional. State properties user wish to include with
                 this state. Full replace of the current state_metadata.
 
@@ -832,7 +893,12 @@ class RecommenderClient(metaclass=RecommenderClientMeta):
         )
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -851,7 +917,6 @@ class RecommenderClient(metaclass=RecommenderClientMeta):
         the recommender.*.list IAM permission for the specified
         recommender.
 
-
         .. code-block:: python
 
             from google.cloud import recommender_v1beta1
@@ -972,12 +1037,20 @@ class RecommenderClient(metaclass=RecommenderClientMeta):
         )
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # This method is paged; wrap the response in a pager, which provides
         # an `__iter__` convenience method.
         response = pagers.ListRecommendationsPager(
-            method=rpc, request=request, response=response, metadata=metadata,
+            method=rpc,
+            request=request,
+            response=response,
+            metadata=metadata,
         )
 
         # Done; return the response.
@@ -995,7 +1068,6 @@ class RecommenderClient(metaclass=RecommenderClientMeta):
         r"""Gets the requested recommendation. Requires the
         recommender.*.get IAM permission for the specified recommender.
 
-
         .. code-block:: python
 
             from google.cloud import recommender_v1beta1
@@ -1070,7 +1142,12 @@ class RecommenderClient(metaclass=RecommenderClientMeta):
         )
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -1082,9 +1159,7 @@ class RecommenderClient(metaclass=RecommenderClientMeta):
         ] = None,
         *,
         name: str = None,
-        state_metadata: Sequence[
-            recommender_service.MarkRecommendationClaimedRequest.StateMetadataEntry
-        ] = None,
+        state_metadata: Mapping[str, str] = None,
         etag: str = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
@@ -1102,7 +1177,6 @@ class RecommenderClient(metaclass=RecommenderClientMeta):
         Requires the recommender.*.update IAM permission for the
         specified recommender.
 
-
         .. code-block:: python
 
             from google.cloud import recommender_v1beta1
@@ -1132,7 +1206,7 @@ class RecommenderClient(metaclass=RecommenderClientMeta):
                 This corresponds to the ``name`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-            state_metadata (Sequence[google.cloud.recommender_v1beta1.types.MarkRecommendationClaimedRequest.StateMetadataEntry]):
+            state_metadata (Mapping[str, str]):
                 State properties to include with this state. Overwrites
                 any existing ``state_metadata``. Keys must match the
                 regex ``/^[a-z0-9][a-z0-9_.-]{0,62}$/``. Values must
@@ -1203,7 +1277,12 @@ class RecommenderClient(metaclass=RecommenderClientMeta):
         )
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -1215,9 +1294,7 @@ class RecommenderClient(metaclass=RecommenderClientMeta):
         ] = None,
         *,
         name: str = None,
-        state_metadata: Sequence[
-            recommender_service.MarkRecommendationSucceededRequest.StateMetadataEntry
-        ] = None,
+        state_metadata: Mapping[str, str] = None,
         etag: str = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
@@ -1235,7 +1312,6 @@ class RecommenderClient(metaclass=RecommenderClientMeta):
         Requires the recommender.*.update IAM permission for the
         specified recommender.
 
-
         .. code-block:: python
 
             from google.cloud import recommender_v1beta1
@@ -1265,7 +1341,7 @@ class RecommenderClient(metaclass=RecommenderClientMeta):
                 This corresponds to the ``name`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-            state_metadata (Sequence[google.cloud.recommender_v1beta1.types.MarkRecommendationSucceededRequest.StateMetadataEntry]):
+            state_metadata (Mapping[str, str]):
                 State properties to include with this state. Overwrites
                 any existing ``state_metadata``. Keys must match the
                 regex ``/^[a-z0-9][a-z0-9_.-]{0,62}$/``. Values must
@@ -1336,7 +1412,12 @@ class RecommenderClient(metaclass=RecommenderClientMeta):
         )
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -1348,9 +1429,7 @@ class RecommenderClient(metaclass=RecommenderClientMeta):
         ] = None,
         *,
         name: str = None,
-        state_metadata: Sequence[
-            recommender_service.MarkRecommendationFailedRequest.StateMetadataEntry
-        ] = None,
+        state_metadata: Mapping[str, str] = None,
         etag: str = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
@@ -1368,7 +1447,6 @@ class RecommenderClient(metaclass=RecommenderClientMeta):
         Requires the recommender.*.update IAM permission for the
         specified recommender.
 
-
         .. code-block:: python
 
             from google.cloud import recommender_v1beta1
@@ -1398,7 +1476,7 @@ class RecommenderClient(metaclass=RecommenderClientMeta):
                 This corresponds to the ``name`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-            state_metadata (Sequence[google.cloud.recommender_v1beta1.types.MarkRecommendationFailedRequest.StateMetadataEntry]):
+            state_metadata (Mapping[str, str]):
                 State properties to include with this state. Overwrites
                 any existing ``state_metadata``. Keys must match the
                 regex ``/^[a-z0-9][a-z0-9_.-]{0,62}$/``. Values must
@@ -1467,7 +1545,12 @@ class RecommenderClient(metaclass=RecommenderClientMeta):
         )
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -1484,7 +1567,6 @@ class RecommenderClient(metaclass=RecommenderClientMeta):
         r"""Gets the requested Recommender Config. There is only
         one instance of the config for each Recommender.
 
-
         .. code-block:: python
 
             from google.cloud import recommender_v1beta1
@@ -1564,7 +1646,12 @@ class RecommenderClient(metaclass=RecommenderClientMeta):
         )
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -1582,7 +1669,6 @@ class RecommenderClient(metaclass=RecommenderClientMeta):
         r"""Updates a Recommender Config. This will create a new
         revision of the config.
 
-
         .. code-block:: python
 
             from google.cloud import recommender_v1beta1
@@ -1665,7 +1751,12 @@ class RecommenderClient(metaclass=RecommenderClientMeta):
         )
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -1682,7 +1773,6 @@ class RecommenderClient(metaclass=RecommenderClientMeta):
         r"""Gets the requested InsightTypeConfig. There is only
         one instance of the config for each InsightType.
 
-
         .. code-block:: python
 
             from google.cloud import recommender_v1beta1
@@ -1762,7 +1852,12 @@ class RecommenderClient(metaclass=RecommenderClientMeta):
         )
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -1780,7 +1875,6 @@ class RecommenderClient(metaclass=RecommenderClientMeta):
         r"""Updates an InsightTypeConfig change. This will create
         a new revision of the config.
 
-
         .. code-block:: python
 
             from google.cloud import recommender_v1beta1
@@ -1863,7 +1957,12 @@ class RecommenderClient(metaclass=RecommenderClientMeta):
         )
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
