@@ -13,18 +13,17 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
+from google.protobuf import field_mask_pb2  # type: ignore
 import proto  # type: ignore
 
-from google.cloud.recommender_v1beta1.types import insight
 from google.cloud.recommender_v1beta1.types import (
     insight_type_config as gcr_insight_type_config,
 )
-from google.cloud.recommender_v1beta1.types import recommendation
 from google.cloud.recommender_v1beta1.types import (
     recommender_config as gcr_recommender_config,
 )
-from google.protobuf import field_mask_pb2  # type: ignore
-
+from google.cloud.recommender_v1beta1.types import insight
+from google.cloud.recommender_v1beta1.types import recommendation
 
 __protobuf__ = proto.module(
     package="google.cloud.recommender.v1beta1",
@@ -104,10 +103,22 @@ class ListInsightsRequest(proto.Message):
             described at https://google.aip.dev/160)
     """
 
-    parent = proto.Field(proto.STRING, number=1,)
-    page_size = proto.Field(proto.INT32, number=2,)
-    page_token = proto.Field(proto.STRING, number=3,)
-    filter = proto.Field(proto.STRING, number=4,)
+    parent = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    page_size = proto.Field(
+        proto.INT32,
+        number=2,
+    )
+    page_token = proto.Field(
+        proto.STRING,
+        number=3,
+    )
+    filter = proto.Field(
+        proto.STRING,
+        number=4,
+    )
 
 
 class ListInsightsResponse(proto.Message):
@@ -126,8 +137,15 @@ class ListInsightsResponse(proto.Message):
     def raw_page(self):
         return self
 
-    insights = proto.RepeatedField(proto.MESSAGE, number=1, message=insight.Insight,)
-    next_page_token = proto.Field(proto.STRING, number=2,)
+    insights = proto.RepeatedField(
+        proto.MESSAGE,
+        number=1,
+        message=insight.Insight,
+    )
+    next_page_token = proto.Field(
+        proto.STRING,
+        number=2,
+    )
 
 
 class GetInsightRequest(proto.Message):
@@ -138,7 +156,10 @@ class GetInsightRequest(proto.Message):
             Required. Name of the insight.
     """
 
-    name = proto.Field(proto.STRING, number=1,)
+    name = proto.Field(
+        proto.STRING,
+        number=1,
+    )
 
 
 class MarkInsightAcceptedRequest(proto.Message):
@@ -147,7 +168,7 @@ class MarkInsightAcceptedRequest(proto.Message):
     Attributes:
         name (str):
             Required. Name of the insight.
-        state_metadata (Sequence[google.cloud.recommender_v1beta1.types.MarkInsightAcceptedRequest.StateMetadataEntry]):
+        state_metadata (Mapping[str, str]):
             Optional. State properties user wish to include with this
             state. Full replace of the current state_metadata.
         etag (str):
@@ -155,9 +176,19 @@ class MarkInsightAcceptedRequest(proto.Message):
             Provides optimistic locking.
     """
 
-    name = proto.Field(proto.STRING, number=1,)
-    state_metadata = proto.MapField(proto.STRING, proto.STRING, number=2,)
-    etag = proto.Field(proto.STRING, number=3,)
+    name = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    state_metadata = proto.MapField(
+        proto.STRING,
+        proto.STRING,
+        number=2,
+    )
+    etag = proto.Field(
+        proto.STRING,
+        number=3,
+    )
 
 
 class ListRecommendationsRequest(proto.Message):
@@ -217,10 +248,22 @@ class ListRecommendationsRequest(proto.Message):
             described at https://google.aip.dev/160)
     """
 
-    parent = proto.Field(proto.STRING, number=1,)
-    page_size = proto.Field(proto.INT32, number=2,)
-    page_token = proto.Field(proto.STRING, number=3,)
-    filter = proto.Field(proto.STRING, number=5,)
+    parent = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    page_size = proto.Field(
+        proto.INT32,
+        number=2,
+    )
+    page_token = proto.Field(
+        proto.STRING,
+        number=3,
+    )
+    filter = proto.Field(
+        proto.STRING,
+        number=5,
+    )
 
 
 class ListRecommendationsResponse(proto.Message):
@@ -240,9 +283,14 @@ class ListRecommendationsResponse(proto.Message):
         return self
 
     recommendations = proto.RepeatedField(
-        proto.MESSAGE, number=1, message=recommendation.Recommendation,
+        proto.MESSAGE,
+        number=1,
+        message=recommendation.Recommendation,
+    )
+    next_page_token = proto.Field(
+        proto.STRING,
+        number=2,
     )
-    next_page_token = proto.Field(proto.STRING, number=2,)
 
 
 class GetRecommendationRequest(proto.Message):
@@ -253,7 +301,10 @@ class GetRecommendationRequest(proto.Message):
             Required. Name of the recommendation.
     """
 
-    name = proto.Field(proto.STRING, number=1,)
+    name = proto.Field(
+        proto.STRING,
+        number=1,
+    )
 
 
 class MarkRecommendationClaimedRequest(proto.Message):
@@ -262,7 +313,7 @@ class MarkRecommendationClaimedRequest(proto.Message):
     Attributes:
         name (str):
             Required. Name of the recommendation.
-        state_metadata (Sequence[google.cloud.recommender_v1beta1.types.MarkRecommendationClaimedRequest.StateMetadataEntry]):
+        state_metadata (Mapping[str, str]):
             State properties to include with this state. Overwrites any
             existing ``state_metadata``. Keys must match the regex
             ``/^[a-z0-9][a-z0-9_.-]{0,62}$/``. Values must match the
@@ -272,9 +323,19 @@ class MarkRecommendationClaimedRequest(proto.Message):
             Provides optimistic locking.
     """
 
-    name = proto.Field(proto.STRING, number=1,)
-    state_metadata = proto.MapField(proto.STRING, proto.STRING, number=2,)
-    etag = proto.Field(proto.STRING, number=3,)
+    name = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    state_metadata = proto.MapField(
+        proto.STRING,
+        proto.STRING,
+        number=2,
+    )
+    etag = proto.Field(
+        proto.STRING,
+        number=3,
+    )
 
 
 class MarkRecommendationSucceededRequest(proto.Message):
@@ -283,7 +344,7 @@ class MarkRecommendationSucceededRequest(proto.Message):
     Attributes:
         name (str):
             Required. Name of the recommendation.
-        state_metadata (Sequence[google.cloud.recommender_v1beta1.types.MarkRecommendationSucceededRequest.StateMetadataEntry]):
+        state_metadata (Mapping[str, str]):
             State properties to include with this state. Overwrites any
             existing ``state_metadata``. Keys must match the regex
             ``/^[a-z0-9][a-z0-9_.-]{0,62}$/``. Values must match the
@@ -293,9 +354,19 @@ class MarkRecommendationSucceededRequest(proto.Message):
             Provides optimistic locking.
     """
 
-    name = proto.Field(proto.STRING, number=1,)
-    state_metadata = proto.MapField(proto.STRING, proto.STRING, number=2,)
-    etag = proto.Field(proto.STRING, number=3,)
+    name = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    state_metadata = proto.MapField(
+        proto.STRING,
+        proto.STRING,
+        number=2,
+    )
+    etag = proto.Field(
+        proto.STRING,
+        number=3,
+    )
 
 
 class MarkRecommendationFailedRequest(proto.Message):
@@ -304,7 +375,7 @@ class MarkRecommendationFailedRequest(proto.Message):
     Attributes:
         name (str):
             Required. Name of the recommendation.
-        state_metadata (Sequence[google.cloud.recommender_v1beta1.types.MarkRecommendationFailedRequest.StateMetadataEntry]):
+        state_metadata (Mapping[str, str]):
             State properties to include with this state. Overwrites any
             existing ``state_metadata``. Keys must match the regex
             ``/^[a-z0-9][a-z0-9_.-]{0,62}$/``. Values must match the
@@ -314,9 +385,19 @@ class MarkRecommendationFailedRequest(proto.Message):
             Provides optimistic locking.
     """
 
-    name = proto.Field(proto.STRING, number=1,)
-    state_metadata = proto.MapField(proto.STRING, proto.STRING, number=2,)
-    etag = proto.Field(proto.STRING, number=3,)
+    name = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    state_metadata = proto.MapField(
+        proto.STRING,
+        proto.STRING,
+        number=2,
+    )
+    etag = proto.Field(
+        proto.STRING,
+        number=3,
+    )
 
 
 class GetRecommenderConfigRequest(proto.Message):
@@ -335,7 +416,10 @@ class GetRecommenderConfigRequest(proto.Message):
             -  ``organizations/[ORGANIZATION_ID]/locations/[LOCATION]/recommenders/[RECOMMENDER_ID]/config``
     """
 
-    name = proto.Field(proto.STRING, number=1,)
+    name = proto.Field(
+        proto.STRING,
+        number=1,
+    )
 
 
 class UpdateRecommenderConfigRequest(proto.Message):
@@ -352,12 +436,19 @@ class UpdateRecommenderConfigRequest(proto.Message):
     """
 
     recommender_config = proto.Field(
-        proto.MESSAGE, number=1, message=gcr_recommender_config.RecommenderConfig,
+        proto.MESSAGE,
+        number=1,
+        message=gcr_recommender_config.RecommenderConfig,
     )
     update_mask = proto.Field(
-        proto.MESSAGE, number=2, message=field_mask_pb2.FieldMask,
+        proto.MESSAGE,
+        number=2,
+        message=field_mask_pb2.FieldMask,
+    )
+    validate_only = proto.Field(
+        proto.BOOL,
+        number=3,
     )
-    validate_only = proto.Field(proto.BOOL, number=3,)
 
 
 class GetInsightTypeConfigRequest(proto.Message):
@@ -376,7 +467,10 @@ class GetInsightTypeConfigRequest(proto.Message):
             -  ``organizations/[ORGANIZATION_ID]/locations/global/recommenders/[INSIGHT_TYPE_ID]/config``
     """
 
-    name = proto.Field(proto.STRING, number=1,)
+    name = proto.Field(
+        proto.STRING,
+        number=1,
+    )
 
 
 class UpdateInsightTypeConfigRequest(proto.Message):
@@ -393,12 +487,19 @@ class UpdateInsightTypeConfigRequest(proto.Message):
     """
 
     insight_type_config = proto.Field(
-        proto.MESSAGE, number=1, message=gcr_insight_type_config.InsightTypeConfig,
+        proto.MESSAGE,
+        number=1,
+        message=gcr_insight_type_config.InsightTypeConfig,
     )
     update_mask = proto.Field(
-        proto.MESSAGE, number=2, message=field_mask_pb2.FieldMask,
+        proto.MESSAGE,
+        number=2,
+        message=field_mask_pb2.FieldMask,
+    )
+    validate_only = proto.Field(
+        proto.BOOL,
+        number=3,
     )
-    validate_only = proto.Field(proto.BOOL, number=3,)
 
 
 __all__ = tuple(sorted(__protobuf__.manifest))
